##  test.R
##  
##  written by:
##
##  Bruce E. Hansen
##  Department of Economics
##  Social Science Building
##  University of Wisconsin
##  Madison, WI 53706-1393
##  behansen@wisc.edu
##  http://www.ssc.wisc.edu/~bhansen/
##   
##  This is a R program file. It tests for threshold effects
##  in autoregressive models.
##  It calls the R procedures thr_est.R, thr_test.R, and
##  thr_het.R.  See these files for further documentation.

source("Z:\\thr_est.R")
source("Z:\\thr_test.R")
source("Z:\\thr_het.R")

graph <- 0        # Set graph=1 to view the graph else set set graph=0
omit <- 0         # lags omitted from autoregression, if all included set omit=0       
h <- 1            # set h=1 for heteroskedasticity-correction else set h=0                     
name <- "UR"      # name of series                   
trim_per <- .15   # percentage of sample to trim from ends for test, e.g., trim_per=.15     
rep <- 1000       # number of bootstrap replications 
p <- 12           # autoregressive order             


# Load Data into vector y #
u <- read.table("z:\\lhmu.dat")
c <- read.table("z:\\lhmc.dat")
u <- as.matrix(u)
c <- as.matrix(c)
t1 <- floor(u[1])
ts <- 1959
s1 <- (ts-t1)*12+3
n <- nrow(u)
y <- as.matrix((u[s1:n]/c[s1:n])*100)
n <- nrow(y)

# Taking First Differences #
y <- as.matrix(y[2:n]-y[1:(n-1)])

# Create data matrix (lags, etc) #

rd <- 1000
n <- nrow(dy)
dat <- y[(1+p):n]
names <- name
for (j in 1:p){
    if (sum(omit==j)==0){
        dat <- cbind(dat,y[(1+p-j):(n-j)])
        if (j<10){ pn <- paste(c("0"),j,sep="")
        }else{ pn <- as.character(j)}
        namej <- paste(c("Y(t-"),pn,c(")"),sep="")
        names <- rbind(names,namej)    
    }  
}
xi <- as.matrix(seq(2,ncol(dat),by=1))
ya <- y[p:(n-1)]
for (j in 2:12){
    ya <- ya + y[(1+p-j):(n-j)]
    yj <- ya
    yj <- round(yj*rd)/rd
    dat <- cbind(dat,yj)
    if (j<10){ pn <- paste(c("0"),j,sep="")
    }else{ pn <- as.character(j)}
    namej <- paste(c("Y(t-"),pn,c(")"),sep="")
    names <- rbind(names,namej)  
}

for (a in 1:1){
cat ("Sample Period ", ts,"~",floor((ts+n/12)),sep="","\n")
cat ("\n")
cat ("Tests for Threshold in SETAR Model", "\n")
cat ("\n")
cat ("d  ", "Qhat     ", "SSE     ", "F-test  ", "P-value  ", "\n")
cat ("\n")
d <- 2 
while (d<=12){
    qi <- 1+d
    out1 <- thr_est(dat,names,1,xi,qi,1)
    if (h==0) out2 <- thr_test(dat,1,xi,qi,trim_per,rep)
    if (h==1) out2 <- thr_het(dat,1,xi,qi,trim_per,rep)
    cat (d," ",out1$qhat," ",out1$sse," ",out2$f_test," ",out2$p_value, "\n")
    d <- d+1
}
cat ("\n")
cat ("\n")
cat ("\n")

cat ("Tests for Threshold in Long-Difference Model", "\n")
cat ("\n")
cat ("d  ", "Qhat     ", "SSE     ", "F-test  ", "P-value  ", "\n")
cat ("\n")
d <- 2 
while (d<=12){
    qi <- p+d
    out1 <- thr_est(dat,names,1,xi,qi,1)
    if (h==0) out2 <- thr_test(dat,1,xi,qi,trim_per,rep)
    if (h==1) out2 <- thr_het(dat,1,xi,qi,trim_per,rep)
    cat (d," ",out1$qhat," ",out1$sse," ",out2$f_test," ",out2$p_value, "\n")
    d <- d+1
}
}

save.image(file = "testout.RData")


